Param(
    [string] $rgName,
    [string] $stageName,
    [string] $templateFile,
    [string] $baseDir = '.',
    [string] $templateParametersString,
    [object] $templateParameters,
    [bool] $complete
)

Import-module "${baseDir}/utils.ps1" -Force

Write-Host "Starting deployment for ${stageName} stage using template ${templateFile}"

if ($null -ne $templateParametersString -and "" -ne $templateParametersString)
{
    $psObjectParameters = $templateParametersString | convertfrom-json
    $tmplParameters = ConvertPSObjectToHashtable $psObjectParameters
}
else {
    $tmplParameters = ConvertPSObjectToHashtable $templateParameters
}

$result = $null;

if ($complete) 
{
    $result = New-AzResourceGroupDeployment -ResourceGroupName $rgName -TemplateFile $templateFile -TemplateParameterObject $tmplParameters -Mode Complete -Force -Verbose
}
else {
    $result = New-AzResourceGroupDeployment -ResourceGroupName $rgName -TemplateFile $templateFile -TemplateParameterObject $tmplParameters -Mode Incremental -Verbose 
}

Write-Host "Deployment for ${stageName} stage completed"

return $result;